==> jc-1.4.0.tar.gz: javax/swing/plaf/ViewportUI.h <==
// public abstract class javax.swing.plaf.ViewportUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 6b89c06da8440050 javax_swing_plaf_ViewportUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ViewportUI_H_
#define _JC_javax_swing_plaf_ViewportUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ViewportUI$sub_refs	_jc_javax_swing_plaf_ViewportUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ViewportUI$sub_nonrefs	_jc_javax_swing_plaf_ViewportUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ViewportUI$refs	_jc_javax_swing_plaf_ViewportUI$refs;
typedef struct _jc_javax_swing_plaf_ViewportUI$nonrefs	_jc_javax_swing_plaf_ViewportUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ViewportUI$object	_jc_javax_swing_plaf_ViewportUI$object;

typedef const struct _jc_javax_swing_plaf_ViewportUI$vmethods	_jc_javax_swing_plaf_ViewportUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ViewportUI$vtable	_jc_javax_swing_plaf_ViewportUI$vtable;
typedef const struct _jc_javax_swing_plaf_ViewportUI$vtype	_jc_javax_swing_plaf_ViewportUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ViewportUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ViewportUI$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_ViewportUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ViewportUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ViewportUI$vmethods	javax_swing_plaf_ViewportUI;
};

// Vtype
struct _jc_javax_swing_plaf_ViewportUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ViewportUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ViewportUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ViewportUI$refs {
    _jc_javax_swing_plaf_ViewportUI$sub_refs	javax_swing_plaf_ViewportUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ViewportUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ViewportUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ViewportUI$sub_nonrefs	javax_swing_plaf_ViewportUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ViewportUI$object {
	_jc_javax_swing_plaf_ViewportUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ViewportUI$vtype	*vtype;
	_jc_javax_swing_plaf_ViewportUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ViewportUI$vtype _jc_javax_swing_plaf_ViewportUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ViewportUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ViewportUI$class_object;

#endif	/* _JC_javax_swing_plaf_ViewportUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/ViewportUI.h <==
// public abstract class javax.swing.plaf.ViewportUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 6b89c06da8440050 javax_swing_plaf_ViewportUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ViewportUI_H_
#define _JC_javax_swing_plaf_ViewportUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ViewportUI$sub_refs	_jc_javax_swing_plaf_ViewportUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ViewportUI$sub_nonrefs	_jc_javax_swing_plaf_ViewportUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ViewportUI$refs	_jc_javax_swing_plaf_ViewportUI$refs;
typedef struct _jc_javax_swing_plaf_ViewportUI$nonrefs	_jc_javax_swing_plaf_ViewportUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ViewportUI$object	_jc_javax_swing_plaf_ViewportUI$object;

typedef const struct _jc_javax_swing_plaf_ViewportUI$vmethods	_jc_javax_swing_plaf_ViewportUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ViewportUI$vtable	_jc_javax_swing_plaf_ViewportUI$vtable;
typedef const struct _jc_javax_swing_plaf_ViewportUI$vtype	_jc_javax_swing_plaf_ViewportUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ViewportUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ViewportUI$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_ViewportUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ViewportUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ViewportUI$vmethods	javax_swing_plaf_ViewportUI;
};

// Vtype
struct _jc_javax_swing_plaf_ViewportUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ViewportUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ViewportUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ViewportUI$refs {
    _jc_javax_swing_plaf_ViewportUI$sub_refs	javax_swing_plaf_ViewportUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ViewportUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ViewportUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ViewportUI$sub_nonrefs	javax_swing_plaf_ViewportUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ViewportUI$object {
	_jc_javax_swing_plaf_ViewportUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ViewportUI$vtype	*vtype;
	_jc_javax_swing_plaf_ViewportUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ViewportUI$vtype _jc_javax_swing_plaf_ViewportUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ViewportUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ViewportUI$class_object;

#endif	/* _JC_javax_swing_plaf_ViewportUI_H_ */
